/********* BEST VIEWED IN 80 COLUMNS ** BEST VIEWED IN 80 COLUMNS **************
*
* Small ToughCase+ Bracket
* Benjamen Johnson <workshop.electronsmith.com>
* 20210426
* openSCAD Version: 2019.05 
* Licesnse: Creative Commons - Attribution - Share Alike
*           https://creativecommons.org/licenses/by-sa/4.0/
*******************************************************************************/
/*[Hidden]*/
version="V1.0";

COUNTERBORE=0;COUNTERSINK=1;INSERTNUT=2;
$dl=0.01;

/*[Bracket Parameters]*/
/*******************************************************************************
*
*******************************************************************************/
// Height of the bracket
bracket_height = 47;

// Thickness of the bracket
wall_thickness = 4;

// Thickness of the screw reinforcement area
reinforce_thickness = 2;

// Width of the screw reinforcement area
reinforce_width = 48;

// Diameter of the detent the holds the case in place
detent_dia = 3;

REINFORCEMENT = [reinforce_width,reinforce_thickness];

/*[ToughCase Measurements]*/
/*******************************************************************************
*
*******************************************************************************/
// Width of the ToughCase+ arounf the middle
case_width = 92;

// Depth of the ToughCase+ around the middle
case_depth = 48;

// How thick is the catch for the buckle?
catch_thickness = 2.5;

// How high does the catch stick out in top of the case?
overhang=3.5;

CASE_DEF = [case_depth,case_width];

/*[Hole Parameters]*/
/*******************************************************************************
*
*      |----------|<-- counter_diameter
* ----  ---------- ---
*   |   \        /  |
*   |    \      /   | <--counter_depth
* total_  |    |   ---       
* depth   |    |
*   |     |    |
*   |     |    |
* -----    ----
*         |----|<-- hole_dia
*
*******************************************************************************/
// Mounting Holes in the end?
end_mounting_holes=1;//[0:No,1:Yes]

// Mouting Holes in the side?
side_mounting_holes=1; //[0:No,1:Yes]

// What type of hole to make
hole_type =0;//[0:Counterbore, 1:Countersink, 2:Insert Nut]

// Distance between holes 
vert_hole_dist = 25.4;//[0:0.1:50]

// Distance between holes 
horiz_hole_dist = 25.4;//[0:0.1:50]

// Mounting hole diameter
hole_dia = 5;

// What angle countersink?
countersink_angle = 82; // [60,82,90,100,110,120]

// Depth of countersink or counterbore
counter_depth = 2;

// Counter bore diameter
counter_dia = 8;

// Nut depth
nut_depth = 4;

// What is the wrench size of the hex nut to be pressed
nut_size = 8.62;

// Calculate the point to point diameter of the pressed nut
pt_to_pt_hex_nut_dia = 2*(nut_size/2)/cos(30);

/*[Stamp Options]*/
/*******************************************************************************
* Stamp Options
*******************************************************************************/
// Which font do you want to use
font = "REGISTRATION PLATE UK:style=Bold";

// How big you want the text
font_size = 12;//[0:0.5:8]

// How thick the font is (back to front)
font_thickness = 0.6;

/*******************************************************************************
* Make the bracket
*******************************************************************************/
a=-12;b=-11.5;

difference(){
    translate([0,0,-bracket_height/2])
    linear_extrude(height=bracket_height,convexity=10,$fn=50)
        union(){
            difference(){
                // make the outline
                offset(r=wall_thickness)square(CASE_DEF,center=true);
                square(CASE_DEF,center=true);
    
                // cut out opening
                translate([a,b])    
                square(CASE_DEF,center=true);
            
                // cut off end at an angle
                translate([-a,-case_width/2+2])
                rotate([0,0,40])
                square([10,10],center=true);
            }//end difference
            
            // add hook
            translate([-case_depth/2+(overhang-wall_thickness)/2,case_width/2+b-wall_thickness/2])
            square([wall_thickness+overhang,wall_thickness],center=true);
            
            // add latch detent
            translate([case_depth/2-detent_dia/2-catch_thickness,-case_width/2])
            circle(d=detent_dia);
            
            // add extra meat to the end
            if(end_mounting_holes)
                translate([0,case_width/2+wall_thickness+reinforce_thickness/2])
                square(REINFORCEMENT,center=true);
            
            // add extra meat to the side
            if(side_mounting_holes)
                translate([case_depth/2+wall_thickness+reinforce_thickness/2,0])
                rotate(90)
                square(REINFORCEMENT,center=true);
    
        }//end union
    
    // holes in end
    if(end_mounting_holes){  
        translate([horiz_hole_dist/2,case_width/2-$dl,-vert_hole_dist/2])
        rotate([90,0,0])
        screw_hole();
            
        translate([-horiz_hole_dist/2,case_width/2-$dl,-vert_hole_dist/2])
        rotate([90,0,0])
        screw_hole();
        
        translate([horiz_hole_dist/2,case_width/2-$dl,vert_hole_dist/2])
        rotate([90,0,0])
        screw_hole();
            
        translate([-horiz_hole_dist/2,case_width/2-$dl,vert_hole_dist/2])
        rotate([90,0,0])
        screw_hole();
    } //end if
    
    //holes in side 
    if(side_mounting_holes){     
        translate([case_depth/2-$dl,horiz_hole_dist/2,-vert_hole_dist/2])
        rotate([90,0,-90])
        screw_hole();
            
        translate([case_depth/2-$dl,-horiz_hole_dist/2,-vert_hole_dist/2])
        rotate([90,0,-90])
        screw_hole();
        
        translate([case_depth/2-$dl,horiz_hole_dist/2,vert_hole_dist/2])
        rotate([90,0,-90])
        screw_hole();
            
        translate([case_depth/2-$dl,-horiz_hole_dist/2,vert_hole_dist/2])
        rotate([90,0,-90])
        screw_hole();
    }//end if 
        
    // stamp version   
    translate([case_depth/2+wall_thickness-font_thickness,reinforce_width/2+font_size/2+3,0])    
    rotate([0,90,0])    
    stamp_version(version, font_size, font_thickness);
}//end difference

/*******************************************************************************
* Module for drilling counterbored or countersuck screw holes
*******************************************************************************/
module screw_hole(){
// Stick above the plane to get a good cut in uneven surfaces    
hole_depth = 10;
    
// Calculate the diameter of the countersink hole
countersink_dia = 2*tan(countersink_angle/2)*counter_depth+hole_dia;

    union(){
        translate([0,0,-hole_depth/2])
        cylinder(d=hole_dia,h=hole_depth,center=true,$fn=25);
        
        if(hole_type == COUNTERBORE)
            translate([0,0,-counter_depth/2])
            cylinder(d=counter_dia,h=counter_depth,center=true,$fn=25);
        
        else if(hole_type == COUNTERSINK)
            translate([0,0,-counter_depth/2])
            cylinder(d2=countersink_dia,d1=hole_dia,h=counter_depth,center=true,$fn=25);
        
        if(hole_type == INSERTNUT)
            translate([0,0,-nut_depth/2])
            cylinder(d=pt_to_pt_hex_nut_dia,h=nut_depth,center=true,$fn=6);

    }// end union
}

/*******************************************************************************
* Module for putting the version number on the print
*******************************************************************************/
module stamp_version(version_text,size,thickness){
    color("white")
    linear_extrude(height = thickness)
        text(text = version_text, font = font, size = size, valign="center",halign = "center");
} // end module